@@ -7,11 +7,12 @@ package Object::String;
 use Unicode::Normalize;
 use List::Util;
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 # ABSTRACT: A string object for Perl 5
 
 use Moo;
+use namespace::clean;
 
 
 
@@ -231,7 +232,7 @@ sub right {
 
 sub underscore {
     my $self = shift;
-    $self->{string} =~ tr/ -/_/;
+    $self->{string} = $self->transliterate(' -', '_')->string;
     $self->{string} =~ s/::/\//g;
     $self->{string} =~ s/^([A-Z])/_$1/;
     $self->{string} =~ s/([A-Z]+)([A-Z][a-z])/$1_$2/g;
@@ -243,12 +244,7 @@ sub underscore {
 sub underscored { shift->underscore; }
 
 
-sub dasherize {
-    my $self = shift;
-    $self->{string} = $self->underscore->string;
-    $self->{string} =~ tr/_/-/;
-    return $self;
-}
+sub dasherize { shift->underscore->transliterate('_', '-'); }
 
 
 sub camelize {
@@ -370,11 +366,7 @@ sub strip_punctuation {
 }
 
 
-sub swapcase {
-    my $self = shift;
-    $self->{string} =~ tr/a-zA-Z/A-Za-z/;
-    return $self;
-}
+sub swapcase { shift->transliterate('a-zA-Z', 'A-Za-z'); }
 
 
 sub concat {
@@ -414,11 +406,7 @@ sub quote_meta {
 }
 
 
-sub rot13 {
-    my $self = shift;
-    $self->{string} =~ tr/A-Za-z/N-ZA-Mn-za-m/;
-    return $self;
-}
+sub rot13 { shift->transliterate('A-Za-z', 'N-ZA-Mn-za-m'); }
 
 
 sub say { CORE::say shift->string; }
@@ -440,12 +428,8 @@ sub titlecase { shift->titleize }
 
 sub squeeze {
     my ($self, $keep) = @_;
-    if(defined $keep) {
-        $self->{string} =~ eval "\$self->{string} =~ tr/$keep//cs";
-    }
-    else {
-        $self->{string} =~ eval "\$self->{string} =~ tr///cs";
-    }
+    $keep = '' unless defined $keep;
+    $self->{string} =~ eval "\$self->{string} =~ tr/$keep//cs";
     return $self;
 }
 
@@ -456,6 +440,13 @@ sub shuffle {
     return $self;
 }
 
+
+sub transliterate { 
+    my ($self, $str1, $str2) = @_;
+    $self->{string} =~ eval "\$self->{string} =~ tr/$str1/$str2/";
+    return $self;
+}
+
 no Moo;
 
 use base 'Exporter';
@@ -467,7 +458,6 @@ our @EXPORT = qw {
 
 sub str {
     my $string = join ' ', @_;
-
     return Object::String->new(string => $string);
 }
 
@@ -485,7 +475,7 @@ Object::String - A string object for Perl 5
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
@@ -518,7 +508,7 @@ Aliases: C<to_string>
 
 =head2 to_string
 
-An alias to C<string>
+An alias to C<string>.
 
 =head2 to_lower
 
@@ -558,14 +548,14 @@ Returns the length of a string.
 
 =head2 ensure_left($prefix)
 
-Ensures the string is beginning with $prefix.
+Ensures the string is beginning with C<$prefix>.
 
     say str('dir')->ensure_left('/')->string;   # /dir
     say str('/dir')->ensure_left('/')->string;  # /dir
 
 =head2 ensure_right($suffix)
 
-Ensures the string is ending with $suffix.
+Ensures the string is ending with C<$suffix>.
 
     say str('/dir')->ensure_right('/')->string;     # /dir/
     say str('/dir/')->ensure_right('/')->string;    # /dir/
@@ -602,7 +592,7 @@ An alias to C<clean>.
 
 =head2 repeat($n)
 
-Repeats a string n times.
+Repeats a string C<$n> times.
 Aliases: C<times>
 
     say str('test')->repeat(3)->string; # testtesttest
@@ -613,21 +603,21 @@ An alias to C<repeat>.
 
 =head2 starts_with($str)
 
-Tests if the string starts with $str.
+Tests if the string starts with C<$str>.
 
     str('test')->starts_with('te');     # true
     str('test')->starts_with('z');      # false
 
 =head2 ends_with($str)
 
-Tests if the string ends with $str.
+Tests if the string ends with C<$str>.
 
     str('test')->ends_with('st');   # true
     str('test')->ends_with('z');    # false
 
 =head2 contains($str)
 
-Tests if the string contains $str.
+Tests if the string contains C<$str>.
 Aliases: C<include>
 
     str('test')->contains('es');    # true
@@ -722,20 +712,20 @@ Tests if a string is empty.
 
 =head2 count($str)
 
-Counts the occurrences of $str in the string.
+Counts the occurrences of C<$str> in the string.
 
     say str('This is a test')->count('is'); # 2
 
 =head2 left($count)
 
-Returns a substring of $count characters from the left.
+Returns a substring of C<$count> characters from the left.
 
     say str('This is a test')->left(3)->string;     # Thi
     say str('This is a test')->left(-3)->string;    # est
 
 =head2 right($count)
 
-Returns a substring of $count characters from the right
+Returns a substring of C<$count> characters from the right.
 
     say str('This is a test')->right(3)->string;    # est
     say str('This is a test')->right(-3)->string;   # Thi
@@ -792,17 +782,17 @@ Escapes some HTML entities : &"'<>
 
 Unescapes some HTML entities : &"'<>
 
-=head2 index_left($substr, $position)
+=head2 index_left($substr[, $position])
 
-Searches for a substring within another from a position. If $position is
+Searches for a substring within another from a position. If C<$position> is
 not specified, it begins from 0.
 
     say str('this is a test')->index_left('is');        # 2
     say str('this is a test')->index_right('is', 3);    # 5
 
-=head2 index_right($substr, $position)
+=head2 index_right($substr[, $position])
 
-Searches from right for a substring within another from a position. If $position 
+Searches from right for a substring within another from a position. If C<$position> 
 is not specified, it begins from 0.
 
     say str('this is a test')->index_right('is');       # 5
@@ -820,27 +810,30 @@ Transforms the input into a human friendly form.
 
     say str('-this_is a test')->humanize->string; # This is a test
 
-=head2 pad_left($count, $char)
+=head2 pad_left($count[, $char])
 
-Pad left the string with $count $char.
+Pad left the string with C<$count> C<$char>. 
+If C<$char> is not specified, a space is used.
 
     say str('hello')->pad_left(3)->string;          # hello
     say str('hello')->pad_left(5)->string;          # hello
     say str('hello')->pad_left(10)->string;         #      hello
     say str('hello')->pad_left(10, '.')->string;    # .....hello
 
-=head2 pad_right($count, $char)
+=head2 pad_right($count[, $char])
 
-Pad right the string with $count $char.
+Pad right the string with C<$count> C<$char>.
+If C<$char> is not specified, a space is used.
 
     say str('hello')->pad_right(3)->string;         # hello
     say str('hello')->pad_right(5)->string;         # hello
     say str('hello')->pad_right(10)->string;        # "hello     "
     say str('hello')->pad_left(10, '.')->string;    # hello.....
 
-=head2 pad($count, $char)
+=head2 pad($count[, $char])
 
-Pad the string with $count $char.
+Pad the string with C<$count> C<$char>.
+If C<$char> is not specified, a space is used.
 
     say str('hello')->pad(3)->string;       # hello
     say str('hello')->pad(5)->string;       # hello
@@ -872,7 +865,7 @@ Swaps the case of the string.
 
     say str('TeSt')->swapcase->string; # tEsT
 
-=head2 concat($str1, ...)
+=head2 concat($str1[, ...])
 
 Concats multiple strings.
 Aliases: C<suffix>
@@ -880,16 +873,16 @@ Aliases: C<suffix>
     say str('test')->concat('test')->string;            # testtest
     say str('test')->concat('test', 'test')->string;    # testtesttest
 
-=head2 suffix($str1, ...)
+=head2 suffix($str1[, ...])
 
 An alias to C<concat>.
 
-=head2 prefix($str1, ...)
+=head2 prefix($str1[, ...])
 
-Prefix the string with $str1, ...
+Prefix the string with C<$str1, ...>
 
-    say str('test')->prefix('hello')->string;   # hellotest
-    say str('test')->prefix('hello', 'world');  # helloworldtest
+    say str('test')->prefix('hello')->string;           # hellotest
+    say str('test')->prefix('hello', 'world')->string;  # helloworldtest
 
 =head2 reverse
 
@@ -952,6 +945,12 @@ Shuffles a string.
 
     say str('this is a test')->shuffle->string; # tsi  ssati the
 
+=head2 transliterate
+
+Transliterates a string into an another one. It wraps the C<tr()> Perl function.
+
+    say str('test')->transliterate('a-z', 'A-Z')->string; # TEST
+
 =head2 str
 
 Creates and returns a string object.
